pub extern "x86-interrupt" fn handler(
isf: InterruptStackFrame,
error_code: u64,
)Expand description
Panic with the segment selector error code and interrupt stack frame.
pub extern "x86-interrupt" fn handler(
isf: InterruptStackFrame,
error_code: u64,
)Panic with the segment selector error code and interrupt stack frame.